#
# spec file for package starfighter
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           starfighter
Version:        2.4
Release:        1.14
Summary:        Liberate the universe from the evil company WEAPCO
License:        GPL-3.0-or-later
Group:          Amusements/Games/Action/Arcade
URL:            https://pr-starfighter.github.io/
Source0:        https://github.com/pr-starfighter/%{name}/releases/download/v%{version}/starfighter-%{version}-src.tar.gz
Source1:        %{name}-icons.tar
# PATCH-FEATURE-UPSTREAM https://github.com/pr-starfighter/starfighter/pull/24
Patch0:         appdata.patch
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(sdl)

%description
Project: Starfighter is an old school 2D shoot 'em up. In the game you take on
the role of a rebel pilot called Chris, who is attempting to overthrow a
military corporation called Weapco. Weapco has seized control of the known
universe and currently rules it with an iron fist. Chris can no longer stand
back and watch as millions of people suffer and die. He steals an experimental
craft known as "Firefly" and begins his mission to fight his way to Sol,
freeing key systems along the way. The game opens with Chris attempting to
escape a Weapco patrol that has intercepted him.

%lang_package

%prep
%setup -q -a 1 -n %{name}-%{version}-src
%patch0 -p1
sed -i 's/\r$//' README.txt

%build
./autogen.sh
%configure
%make_build

%install
%make_install

# install icons
for i in 16 32 48 64 72 96 128 ; do
    install -Dm 0644 icons/%{name}_${i}x${i}.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done

# remove duplicate docs
rm -fr %{buildroot}%{_datadir}/doc/%{name}

%suse_update_desktop_file %{name}
%fdupes -s %{buildroot}%{_prefix}
%find_lang pr-starfighter

%files
%license COPYING LICENSES
%doc README.txt
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/locale/*
%{_mandir}/man6/starfighter.6%{?ext_man}
%{_datadir}/metainfo/%{name}.appdata.xml

%files lang -f pr-starfighter.lang
%dir %{_datadir}/%{name}/locale/*
%dir %{_datadir}/%{name}/locale/*/LC_MESSAGES


%changelog
* Wed Jan  6 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed spec file (language file directories)
* Tue Dec 29 2020 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 2.4
  * Added a Dutch translation contributed by Heimen Stoffels.
  * Made it so that the player starts at the same part of the screen in Classic difficulty as in version 1.1 (which is in the top-left quadrant rather than in the center).
  * Made it so that critical shield (that is, when you have only 1 shield left) causes more smoke particles to be generated.
  * Fixed a bug where Kline could continue circling while running away, causing him to flee diagonally at a rather slow speed (and also allowing you to kill him pretty easily).
  * Fixed a bug which caused music to not get installed properly (it was being installed in the sound directory instead of the music directory).
  * Made the Venus mission start in the same way as version 1.1 in Classic difficulty (albeit with a shorter delay, since the dialog is shorter than it was in version 1.1).
  * Made it so that the game doesn't go unresponsive to the OS when dying or after winning the Venus mission (meaning you don't have to wait for the game to proceed to the Game Over / Credits screen before you can quit the game normally, and also preventing weird bugs if you resize the window during that time).
  * Made it so that resizing the window in the credits screen repositions the credits text to the new center.
  * Simulated the smaller Kline health bars of version 1.1 in Classic difficulty. While Kline's health bar is still the larger size, its display is broken up into sections so that it now perfectly simulates version 1.1's Kline health bar behavior (a previous release already caused the portions of the health bar to be reduced in "steps", so they already behaved as if they were multiple health bars in Classic difficulty).
  * Made it possible to switch to concentrate mode even with the Super Charge in Classic difficulty, as was the case in the original.
  * Caused star position to be recalculated when you resize the window. This prevents weird gaps in the starfield when you make the window bigger in the middle of a mission, for instance.
  * Added an option to compile a binary that will attempt to use the original music. We won't be distributing that music because that is a violation of copyright, but for those who have the music and want to mod it into the game (no pun intended), it is now possible to do this without changing the source code. Simply pass SF_OLD_MUSIC=1 as an option to the configure script and it will attempt to load the original music file names and use them exactly as version 1.1 did.
  * Corrected the damage of micro rockets and triple-spread plasma bullets for Classic difficulty. These were both doubled at some point for balancing, so Classic difficulty now lowers the damage they inflict to their original values.
- Add a language package.
- Add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
* Sat Sep 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.2
  * Fixed some spelling errors.
  * Replaced use of AUDIO_S16 with the correct AUDIO_S16SYS; the
    effect of this is that the old definition could potentially
    cause sound distortions depending on the platform which
    shouldn't happen anymore.
  * Replaced use of "stupid" in some dialog with "foolish", since
    we've been trying to avoid careless sanist rhetoric in projects
    we manage recently. "Foolish" is a more neutral term that
    doesn't carry any negative connotations toward mentally
    disabled people.
  * Updated the starfighter.desktop file to be more complete.
  * Fixed leftover links to the old website.
  * Added a manfile, based on one written by a Debian contributor.
- Update to version 2.3.1
  * Adjusted in-mission dialogs to match the dialogs' timing (with
    one exception, the first Kline encounter, so as not to mess
    with music cues there).
  * Made it so that, during the Kline fight in Classic difficulty,
    Kline's health goes to the health levels of respective stages
    when stage changes. This is done to simulate the behavior of
    the original, where Kline actually had four separate health
    bars that didn't bleed into each other.
  * Fixed a bug in rendering of Unicode text which allowed
    multi-byte Unicode characters to be split into multiple parts.
- Update to version 2.3
  * When someone I'm very close to played Project: Starfighter
    recently, we noticed a major bugs in Project: Starfighter
    pertaining to gamepad control.
- Update to version 2.2.1
  * Full, proper analog control has been implemented both for
    moving the cursor and for moving your ship. This release also
    fixes a problem where controllers with analog triggers
    wouldn't work correctly.
- Update to version 2.2
  * Added Super-Easy mode, which makes enemies weaker, allies
    stronger, and does various other things to make the game much
    easier.
  * Changed the default difficulty mode from 'Normal" to "Easy".
    Beginners should play Easy mode before Normal mode in my
    opinion, and it's easier to go forward one than back one.
  * Fixed the way spread works in Classic difficulty. It previously
    was handled in a special manner because version 1.2 does it
    that way, but it turns out that that was a change introduced
    by version 1.2, and version 1.1 actually had spread just like
    in every other difficulty mode.
  * "Fixed" the way damage is done with the charge cannon in
    Classic difficulty. It's absolutely ridiculous, but the result
    is so staggeringly different I decided it isn't really a
    genuine classic experience without it. Version 1.1's charge
    cannon was so overpowered that some minibosses could be
    one-shotted with a full blast, due to a quirk in how they
    dissipate. This release restores that behavior in Classic
    difficulty only.
  * Added a difficulty indicator to the titles of save slots.
- Update to version 2.1
  * Improved colorblind accessibility by making friendly bolts
    brighter than enemy bolts and by making the HUD's display of
    powered-up status use brighter colors and textured coloring.
    This change also makes it possible to see all information
    through a heavily red-shifted display.
  * Made it so that the Firefly's exhaust is still displayed when
    low on shield, and halved the amount of explosions shown at
    that time. Prior to this change, the explosions (indicating
    low health) replaced the exhaust entirely, which I thought
    was a bit odd.
  * Except in Classic and Nightmare difficulties, the game now
    waits to start the jump-out sequence until all worthwhile
    powerups have been collected. This in particular ensures that
    you always have a chance to collect all the money that bosses
    drop; it was previously very easy to miss large amounts of it.
  * Except in Classic difficulty, powerups now move outward from
    their ships at only half the speed they used to. This is meant
    to stop them from spreading out incredibly far from the source.
  * Various fixes and improvements, including improvements to
    Gettext translation support.
* Mon Mar 30 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.0:
  * New URL
  * Full conversion from C++ to C
  * Full support for Unicode and gettext translations
  * Nearly perfected emulation of the original game experience
  * Implemented full window resizing support
- Spec cleanup
* Thu Jan  4 2018 avindra@opensuse.org
- Update to 1.7, announce message is here:
  https://savannah.nongnu.org/forum/forum.php?forum_id=8808
- remove RPM_OPT_FLAGS fix, solved upstream
- remove unnecessary variables passed to `make` and `%%make_install`
- cleanup with spec-cleaner
* Mon Dec 26 2016 ecsos@opensuse.org
- Update to 1.6, announce message is here:
  https://savannah.nongnu.org/forum/forum.php?forum_id=8641
* Tue Jan 19 2016 nemysis@openSUSE.org
- Update to 1.5.1.1, announce message is here:
  https://savannah.nongnu.org/forum/forum.php?forum_id=8443
- Use %%{oversion} instead of 1.5
- Remove Desktop entry file, Upstream have accepted changes
- Add BuildRequires for fdupes and use %%fdupes macro to reduce size of the package
* Tue Jul  7 2015 cfarrell@suse.com
- license update: GPL-3.0+
* Sun Jun 28 2015 nemysis@gmx.ch
- Update to -, announce messages are here:
  Project: Starfighter 1.4 Released
  https://savannah.nongnu.org/forum/forum.php?forum_id=8295
  Project: Starfighter 1.3.3 Released
  https://savannah.nongnu.org/forum/forum.php?forum_id=8275
  Project: Starfighter 1.3.1 Released
  https://savannah.nongnu.org/forum/forum.php?forum_id=8253
  Project: Starfighter 1.3 Released
  https://savannah.nongnu.org/forum/forum.php?forum_id=8249
- Change Url from SourceForge to non-GNU
- Change license GPL-2.0 to GPL-2.0+ and GPL-3.0+ and CC0-1.0 and CC-BY-3.0 and SUSE-Public-Domain
- Change Source0 Web URL
- Change starfighter-icons.tar to use _IxI.png instead of -I.png
- Remove BuildRequires for fdupes, not need for it, make bad Symlinks
  and Game not works
- Add BuildRequires for dos2unix
- Remove BuildRequires for python, zlib-devel, pkgconfig(SDL_image),
  pkgconfig(SDL_mixer)
- Add BuildRequires for pkgconfig(SDL2_image), pkgconfig(SDL2_mixer)
- Correct what fdupes find
- Add sed, Fix RPM_OPT_FLAGS
- Add sed, Correct bad linking
- Change Documentation
* Sun Feb 22 2015 ecsos@opensuse.org
- fix missing data
* Wed Nov 12 2014 nemysis@gmx.ch
- Use BuildRequires pkgconfig(SDL_image), pkgconfig(SDL_mixer) and
  pkgconfig(sdl) instead of SDL-devel, SDL_image-devel and
  SDL_mixer-devel
- Remove BuildRequires for desktop-file-utils and pkgconfig
- Use check for openSUSE %%if 0%%{?suse_version}
- Use symlink for %%fdupes
* Sat Sep 27 2014 nemysis@gmx.ch
- Use pkgconfig instead of pkgconfig(sdl)
- Remove sed and adjust %%make_install, with XRevan86 help
* Sat Sep 27 2014 nemysis@gmx.ch
- Add BuildRequires:  hicolor-icon-theme
* Tue Sep 23 2014 nemysis@gmx.ch
- Readd %%{name}-icons.tar with more icons
* Tue Sep 23 2014 nemysis@gmx.ch
- Use usual Copyright on top
- Update to 1.2, for announce message please look ChangeLog
- Change Summary
- Change license GPLv2 to GPL-2.0
- Change URL
- Change Source to use Web URL
- Use %%{name}.png instead of %%{name}-icons.tar
- Change Desktop entry file
- Add BuildRequires for zlib-devel and fdupes
- Remove BuildRequires for hicolor-icon-theme
- Change dependency pkg-config to pkgconfig(sdl)
- Change description
- Simplify installation handling, use normal build
- Move makefile to Makefile
- Add sed, fix paths
- Use default make %%{?_smp_mflags}
- Add starfighter.changes, was not used before
- Fix permissions
